bio-attention.attention Reference
===============

Here be modules that will make up building blocks of transformers

.. autoclass:: bio_attention.attention.Attention
   :members:

.. autoclass:: bio_attention.attention.RandomAttention
   :members:

.. autoclass:: bio_attention.attention.WindowAttention
   :members:

.. autoclass:: bio_attention.attention.Transformer
   :members:

.. autoclass:: bio_attention.attention.TransformerEncoder
   :members:

.. autoclass:: bio_attention.attention.TransformerDecoder
   :members:

.. autoclass:: bio_attention.attention.Aggregator
   :members: